@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 #Name: ds-mouse.py
 #Depends: python, Gtk, xset
 #Author: Dave (david@daveserver.info)
@@ -11,19 +11,20 @@ import os
 import re
 import gettext
 gettext.install("ds-mouse.py", "/usr/share/locale")
+
 class Error:
     def __init__(self, parent, error):
-        dlg = Gtk.MessageDialog(parent, 0, Gtk.MessageType.ERROR, Gtk.ButtonsType.OK, "Error")
-        dlg.format_secondary_text(error)
+        dlg = Gtk.MessageDialog(parent=parent, flags=0, message_type=Gtk.MessageType.ERROR, buttons=Gtk.ButtonsType.OK, text="Error")
+        dlg.format_secondary_text('%s' % error)
         dlg.run()
         dlg.destroy()
        
 class Success:
     def __init__(self, parent, success):
-         dlg = Gtk.MessageDialog(parent, 0, Gtk.MessageType.INFO, Gtk.ButtonsType.OK, "Success")
-         dlg.format_secondary_text(success)
-         dlg.run()
-         dlg.destroy()
+        dlg = Gtk.MessageDialog(parent=parent, flags=0, message_type=Gtk.MessageType.INFO, buttons=Gtk.ButtonsType.OK, text="Success")
+        dlg.format_secondary_text('%s' % success)
+        dlg.run()
+        dlg.destroy()
        
 class Var: 
     def read(self):        
@@ -51,13 +52,14 @@ class Var:
                     OBJECT=(pieces[1])
                     OBJECT = re.sub(r'\n', '', OBJECT)
                     setattr(var, var.VARIABLE, OBJECT)
-        for line in open(var.CONF_USER_STARTUP):
+        for line in open(var.CONF_USER_STARTUP, "r"):
             if re.search(r'ds-mouse' , line):
                 li=line.strip()
                 if li.startswith("#"):
                     var.startstatus = False
                 else:
                     var.startstatus = True
+                    break
             else:
                 var.startstatus = False
         
@@ -65,8 +67,8 @@ class Var:
         WRITE_FILE = Var.CONF_USER_FILE+".tmp"
         READ_FILE = Var.CONF_USER_FILE
         
-        text = file((WRITE_FILE), "w");text.write("");text.close()
-        text = file((WRITE_FILE), "a")
+        text = open((WRITE_FILE), "w");text.write("");text.close()
+        text = open((WRITE_FILE), "a")
         for line in open(READ_FILE, "r"):
             if "#" not in line:
                 if re.search(r'^%s=' % (variable), line):
@@ -94,10 +96,10 @@ class mainWindow(Gtk.Window):
             except:
                 Error(self, _("Could not run ds-mouse -all"))
             else:
-				Success(self, _("All Options Set"))
+                Success(self, _("All Options Set"))
         elif option == 1: #reset motion button
-            acceleration_value = '-1'
-            threshold_value = '-1'
+            acceleration_value = '0'
+            threshold_value = '0'
             Var().write('ACCELERATION', acceleration_value)
             Var().write('THRESHOLD', threshold_value)
             try:
@@ -105,22 +107,29 @@ class mainWindow(Gtk.Window):
             except:
                 Error(self, _("Could not run ds-mouse -a"))
             else:
-				Success(self, _("Mouse Acceleration Reset"))
+                Success(self, _("Mouse Acceleration Reset"))
+                adj1 = Gtk.Adjustment(value=float(acceleration_value), lower=0.0, upper=17.0, step_increment=0.1, page_increment=1.0, page_size=1.0 )
+                self.acceleration.set_adjustment(adj1)
+                adj1 = Gtk.Adjustment(value=float(threshold_value), lower=0.0, upper=101.0, step_increment=1.0, page_increment=1.0, page_size=1.0 )
+                self.threshold.set_adjustment(adj1)
+                
         elif option == 2: #reset size button
-            size_value = '-1'
+            size_value = '0'
             Var().write('SIZE', size_value)
             try:
                 os.system("ds-mouse -s")
             except:
                 Error(self, _("Could not run ds-mouse -s"))
             else:
-				Success(self, _("Cursor Size Reset"))
+                Success(self, _("Cursor Size Reset"))
+                adj1 = Gtk.Adjustment(value=float(size_value), lower=10.0, upper=51.0, step_increment=1.0, page_increment=1.0, page_size=1.0 )
+                self.size.set_adjustment(adj1)
         elif option == 3: #change cursor theme button
             try:
-                os.system("lxappearance")
+                os.system("lxappearance &")
             except:
-                os.system("rxvt-unicode -tr -sh 65 -fg white -T 'cursor theme' -e su -c 'update-alternatives --config x-cursor-theme' ")
-		
+                os.system("rxvt-unicode -tr -sh 65 -fg white -T 'cursor theme' -e su -c 'update-alternatives --config x-cursor-theme' &")
+
     def make_frame(self, text, pos1, pos2, pos3, pos4):
         frame = Gtk.Frame(label=_(text))
         frame.set_border_width(10)
@@ -144,7 +153,7 @@ class mainWindow(Gtk.Window):
     def startup_write(self, FROM, TO):
         TEMP_FILE='/tmp/temp.txt'
         loop=0
-        text = file((TEMP_FILE), "a")
+        text = open((TEMP_FILE), "a")
         for line in open(Var.CONF_USER_STARTUP, "r"):
             if re.search(r'%s' % (FROM), line):
                text.write (TO+"\n")
@@ -159,12 +168,17 @@ class mainWindow(Gtk.Window):
         os.system("mv %s %s && chmod 755 %s" % ((TEMP_FILE), (Var.CONF_USER_STARTUP), (Var.CONF_USER_STARTUP)))
     
     def toggle_startup(self, widget, object):
+        if self.loopkill:
+            self.loopkill=False
+            return
+            
         if self.startup.get_active() == True:
             try:
                 self.startup_write("ds-mouse", "ds-mouse -all &")
             except:
                 Error(self, _("Could not turn on startup \n Please edit ~/.desktop-session/startup manually"))
                 self.startup.set_active(False)
+                self.loopkill=True
             else:
                 Success(self, _("Mouse configuration will load on startup"))
         else:
@@ -173,6 +187,7 @@ class mainWindow(Gtk.Window):
             except:
                 Error(self, _("Could not turn off startup \n Please edit ~/.desktop-session/startup manually"))
                 self.startup.set_active(True)
+                self.loopkill=True
             else:
                 Success(self, _("Mouse configuration will not load on startup"))
 
@@ -189,7 +204,7 @@ class mainWindow(Gtk.Window):
         self.make_frame(_("Mouse Acceleration"),1,1,1,1)
         self.make_label(_("Acceleration (Multiplier)"))
         
-        adj1 = Gtk.Adjustment(float(Var.ACCELERATION), 0.0, 17.0, 0.1, 1.0, 1.0 )
+        adj1 = Gtk.Adjustment(value=float(Var.ACCELERATION), lower=0.0, upper=17.0, step_increment=0.1, page_increment=1.0, page_size=1.0 )
         self.acceleration = Gtk.HScale()
         self.acceleration.set_adjustment(adj1)
         self.acceleration.set_size_request(200, 45)
@@ -199,7 +214,7 @@ class mainWindow(Gtk.Window):
         
         self.make_label(_("Threshold (Pixels)"))
         
-        adj1 = Gtk.Adjustment(float(Var.THRESHOLD), 0.0, 101.0, 1.0, 1.0, 1.0 )
+        adj1 = Gtk.Adjustment(value=float(Var.THRESHOLD), lower=0.0, upper=101.0, step_increment=1.0, page_increment=1.0, page_size=1.0 )
         self.threshold = Gtk.HScale()
         self.threshold.set_adjustment(adj1)
         self.threshold.set_size_request(200, 45)
@@ -207,7 +222,7 @@ class mainWindow(Gtk.Window):
         self.framebox.pack_start(self.threshold, False, False, 0)
         self.threshold.show()
         
-        reset_motion = Gtk.Button(stock=Gtk.STOCK_REVERT_TO_SAVED)
+        reset_motion = Gtk.Button.new_from_icon_name(Gtk.STOCK_REVERT_TO_SAVED, 1)
         reset_motion.connect("clicked", self.apply, 1)
         self.framebox.pack_start(reset_motion, False, False, 0)
         reset_motion.show()
@@ -227,7 +242,7 @@ class mainWindow(Gtk.Window):
         self.make_frame(_("Cursor Size"),2,1,1,1)
         self.make_label(_("Size (in pixels)"))
         
-        adj1 = Gtk.Adjustment(float(Var.SIZE), 10.0, 51.0, 1.0, 1.0, 1.0 )
+        adj1 = Gtk.Adjustment(value=float(Var.SIZE), lower=10.0, upper=51.0, step_increment=1.0, page_increment=1.0, page_size=1.0 )
         self.size = Gtk.HScale()
         self.size.set_adjustment(adj1)
         self.size.set_size_request(200, 45)
@@ -235,7 +250,7 @@ class mainWindow(Gtk.Window):
         self.framebox.pack_start(self.size, False, False, 0)
         self.size.show()
         
-        reset_size = Gtk.Button(stock=Gtk.STOCK_REVERT_TO_SAVED)
+        reset_size = Gtk.Button.new_from_icon_name(Gtk.STOCK_REVERT_TO_SAVED, 1)
         reset_size.connect("clicked", self.apply, 2)
         self.framebox.pack_start(reset_size, False, False, 0)
         reset_size.show()
@@ -243,21 +258,28 @@ class mainWindow(Gtk.Window):
         self.make_frame(_("Cursor Theme"), 2,2,1,1)
         self.make_label(_("May require logout/login \nto see the changes."))
         
-        theme = Gtk.Button(_("Change cursor theme"))
+        theme = Gtk.Button.new_with_mnemonic(_("Change cursor theme"))
         theme.connect("clicked", self.apply, 3)
-        self.framebox.pack_start(theme, False, False, 0)
+        self.framebox.pack_start(theme, False, False, 5)
         theme.show()
         
         self.make_frame(_("Startup"),1,3,2,1)
         self.make_label(_("Enable or Disable mouse configuration on startup\n"))
         
         self.startup = Gtk.Switch()
-        self.startup.set_size_request(0,40)
-        self.framebox.pack_start(self.startup, False, False, 0)
+        self.startup.set_size_request(75,30)
+
+        bbox = Gtk.HBox()
+        self.framebox.pack_start(bbox, False, False, 10)
+        bbox.pack_end(self.startup, False, False, 10)
+        bbox.show()
+
+        self.loopkill=False
         if Var.startstatus :
             self.startup.set_active(True)
         else:
-            self.startup.set_active(False)        
+            self.startup.set_active(False)
+
         self.startup.connect("notify::active", self.toggle_startup)
         self.startup.show()
         
@@ -267,12 +289,12 @@ class mainWindow(Gtk.Window):
         self.grid.attach(buttonbox, 2,4, 1, 1)
         buttonbox.show()
         
-        aply = Gtk.Button(stock=Gtk.STOCK_APPLY)
+        aply = Gtk.Button.new_from_icon_name(Gtk.STOCK_APPLY, 1)
         aply.connect("clicked", self.apply, 0)
         buttonbox.pack_start(aply, False, False, 0)
         aply.show()
         
-        close = Gtk.Button(stock=Gtk.STOCK_CLOSE)
+        close = Gtk.Button.new_from_icon_name(Gtk.STOCK_CLOSE, 1)
         close.connect("clicked", lambda w: Gtk.main_quit())
         buttonbox.pack_start(close, False,False, 0)
         close.show()
